@@ -16,8 +16,10 @@ class Client(object):
         be passed in as kwargs.
         """
         self.use_ssl = kwargs.get('use_ssl', self.use_ssl)
+        self.host = kwargs.get('host', self.host)
         self.scheme = self.use_ssl and 'https://' or 'http://'
         self.options = kwargs
+        self._authorize_url = None
 
         self.client_id = kwargs.get('client_id')
 
@@ -50,10 +52,16 @@ class Client(object):
             'client_secret': self.options.get('client_secret'),
             'code': code,
         }
-        self.token = wrapped_resource(make_request('post', url, options))
+        verify_ssl = self.options.get('verify_ssl', True)
+        self.token = wrapped_resource(
+            make_request('post', url, options, verify_ssl))
         self.access_token = self.token.access_token
         return self.token
 
+    def authorize_url(self):
+        """Return the authorization URL for OAuth2 authorization code flow."""
+        return self._authorize_url
+
     def _authorization_code_flow(self):
         """Build the the auth URL so the user can authorize the app."""
         options = {
@@ -63,7 +71,7 @@ class Client(object):
             'redirect_uri': self.options.get('redirect_uri')
         }
         url = '%s%s/connect' % (self.scheme, self.host)
-        self.authorize_url = '%s?%s' % (url, urlencode(options))
+        self._authorize_url = '%s?%s' % (url, urlencode(options))
 
     def _refresh_token_flow(self):
         """Given a refresh token, obtain a new access token."""
@@ -74,7 +82,9 @@ class Client(object):
             'client_secret': self.options.get('client_secret'),
             'refresh_token': self.options.get('refresh_token')
         }
-        self.token = wrapped_resource(make_request('post', url, options))
+        verify_ssl = self.options.get('verify_ssl', True)
+        self.token = wrapped_resource(
+            make_request('post', url, options, verify_ssl))
         self.access_token = self.token.access_token
 
     def _credentials_flow(self):
@@ -87,7 +97,9 @@ class Client(object):
             'password': self.options.get('password'),
             'grant_type': 'password'
         }
-        self.token = wrapped_resource(make_request('post', url, options))
+        verify_ssl = self.options.get('verify_ssl', True)
+        self.token = wrapped_resource(
+            make_request('post', url, options, verify_ssl))
         self.access_token = self.token.access_token
 
     def _request(self, method, resource, **kwargs):
@@ -101,7 +113,8 @@ class Client(object):
         if hasattr(self, 'client_id'):
             kwargs.update(dict(client_id=self.client_id))
 
-        return wrapped_resource(make_request(method, url, kwargs))
+        verify_ssl = self.options.get('verify_ssl', True)
+        return wrapped_resource(make_request(method, url, kwargs, verify_ssl))
 
     def __getattr__(self, name):
         """Translate an HTTP verb into a request method."""
